@@ -222,7 +222,7 @@ TQString AptProtocol::make_html_form() const
 
 AptProtocol::AptProtocol( const TQCString &pool_socket, const TQCString &app_socket )
     : SlaveBase( "tdeio_apt", pool_socket, app_socket ),
-      m_adept_batch(0), m_parser(0)
+      m_adept_batch(0), m_parser()
 
 {
   TDEStandardDirs* dirs = TDEGlobal::dirs();
@@ -236,15 +236,15 @@ AptProtocol::AptProtocol( const TQCString &pool_socket, const TQCString &app_soc
 
   m_logo_alt = TDEGlobal::config() -> readEntryUntranslated("alt_tag", i18n("KDE on Debian") );
 
-  connect(&m_process, TQT_SIGNAL(token(const TQString&, const TQString&)),
-    this, TQT_SLOT(token_dispatch(const TQString&, const TQString&)));
+  connect(&m_process, TQ_SIGNAL(token(const TQString&, const TQString&)),
+    this, TQ_SLOT(token_dispatch(const TQString&, const TQString&)));
 
   m_adept_batch = new Dpkg(this);
 
   if (m_adept_batch)
   {
-    connect(m_adept_batch, TQT_SIGNAL(token(const TQString&, const TQString&)),
-      this, TQT_SLOT(token_dispatch(const TQString&, const TQString&)));
+    connect(m_adept_batch, TQ_SIGNAL(token(const TQString&, const TQString&)),
+      this, TQ_SLOT(token_dispatch(const TQString&, const TQString&)));
   }
 }
 
@@ -257,7 +257,7 @@ TQString AptProtocol::header_background() const { return m_header_background; }
 
 void AptProtocol::token_dispatch(const TQString& name, const TQString& val)
 {
-  if (m_parser.get())
+  if (m_parser)
     (*m_parser)(this, name, val);
 }
 
